@@ -14,10 +14,10 @@
  * history and logs, available at http://subversion.tigris.org/.
  * ====================================================================
  * @endcopyright
+ *
+ * @file JNIByteArray.h
+ * @brief Interface of the class JNIByteArray
  */
-// JNIByteArray.h: interface for the JNIByteArray class.
-//
-//////////////////////////////////////////////////////////////////////
 
 #if !defined(AFX_JNIBYTEARRAY_H__FB74054F_CD5E_41D5_A4B0_25DE9A8574CF__INCLUDED_)
 #define AFX_JNIBYTEARRAY_H__FB74054F_CD5E_41D5_A4B0_25DE9A8574CF__INCLUDED_
@@ -27,19 +27,33 @@
 #endif // _MSC_VER > 1000
 
 #include <jni.h>
-
+/**
+ * this class holds a java byte array to give easy access to its bytes
+ */
 class JNIByteArray
 {
 private:
-	jbyteArray m_array;
-	jbyte *m_data;
+    /**
+     *  a local reference to the byte array
+     */
+    jbyteArray m_array;
+    /**
+     *  the cache bytes of the byte array
+     */
+    jbyte *m_data;
+    /**
+     * flag that the underlying byte array reference should be deleted at 
+     * destruction
+     */
+    bool m_deleteByteArray;
 public:
-	bool isNull();
-	const signed char * getBytes();
-	int getLength();
-	JNIByteArray(jbyteArray jba);
-	~JNIByteArray();
+    bool isNull();
+    const signed char * getBytes();
+    int getLength();
+    JNIByteArray(jbyteArray jba, bool deleteByteArray = false);
+    ~JNIByteArray();
 
 };
 
-#endif // !defined(AFX_JNIBYTEARRAY_H__FB74054F_CD5E_41D5_A4B0_25DE9A8574CF__INCLUDED_)
+//!defined(AFX_JNIBYTEARRAY_H__FB74054F_CD5E_41D5_A4B0_25DE9A8574CF__INCLUDED_)
+#endif
