@@ -30,6 +30,8 @@
 #include <apr_general.h>
 #endif
 
+#include "svn_types.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif /* __cplusplus */
@@ -55,20 +57,22 @@ extern "C" {
  * Modify when new functionality is added or new interfaces are
  * defined, but all changes are backward compatible.
  */
-#define SVN_VER_MINOR      0
+#define SVN_VER_MINOR      1
 
 /** Patch number.
+ *
+ * @since New in 1.1.
  *
  * Modify for every released patch.
  */
-#define SVN_VER_MICRO      8
+#define SVN_VER_PATCH      4
 
-/** Library version number.
- *
- * Modify whenever there's an incompatible change in the library ABI.
- * ### this is semantically equivalent to SVN_VER_MAJOR. fix...
- */
-#define SVN_VER_LIBRARY    1
+
+/** @deprecated Provided for backward compatibility with the 1.0 API. */
+#define SVN_VER_MICRO      SVN_VER_PATCH
+
+/** @deprecated Provided for backward compatibility with the 1.0 API. */
+#define SVN_VER_LIBRARY    SVN_VER_MAJOR
 
 
 /** Version tag: a string describing the version.
@@ -77,13 +81,14 @@ extern "C" {
  * always see from "svn --version" that the software has been built
  * from the repository rather than a "blessed" distribution.
  *
- * When rolling a tarball, we automatically replace this text with ""
+ * When rolling a tarball, we automatically replace this text with " (r1234)"
+ * (where 1234 is the last revision on the branch prior to the release) 
  * for final releases; in prereleases, it becomes " (Alpha)",
  * " (Beta 1)", etc., as appropriate.
  *
  * Always change this at the same time as SVN_VER_NUMTAG.
  */
-#define SVN_VER_TAG        " (r11084)"
+#define SVN_VER_TAG        " (r13838)"
 
 
 /** Number tag: a string describing the version.
@@ -109,7 +114,7 @@ extern "C" {
  * When rolling a tarball, we automatically replace it with what we
  * guess to be the correct revision number.
  */
-#define SVN_VER_REVISION   11084
+#define SVN_VER_REVISION   0
 
 
 /* Version strings composed from the above definitions. */
@@ -117,7 +122,7 @@ extern "C" {
 /** Version number */
 #define SVN_VER_NUM        APR_STRINGIFY(SVN_VER_MAJOR) \
                            "." APR_STRINGIFY(SVN_VER_MINOR) \
-                           "." APR_STRINGIFY(SVN_VER_MICRO)
+                           "." APR_STRINGIFY(SVN_VER_PATCH)
 
 /** Version number with tag (contains no whitespace) */
 #define SVN_VER_NUMBER     SVN_VER_NUM SVN_VER_NUMTAG
@@ -127,7 +132,97 @@ extern "C" {
 
 
 
-/* ### need runtime query function(s). see apr_version.h for example. */
+/* Version queries and compatibility checks */
+
+/**
+ * Version information. Each library contains a function called
+ * svn_<i>libname</i>_version() that returns a pointer to a statically
+ * allocated object of this type.
+ *
+ * @since New in 1.1.
+ */
+typedef struct svn_version_t
+{
+  int major;                    /**< Major version number */
+  int minor;                    /**< Minor version number */
+  int patch;                    /**< Patch number */
+
+  /**
+   * The verison tag (#SVN_VER_NUMTAG).\ Must always point to a
+   * statically allocated string.
+   */
+  const char *tag;
+} svn_version_t;
+
+/**
+ * Define a static svn_version_t object.
+ * @since New in 1.1.
+ */
+#define SVN_VERSION_DEFINE(name) \
+  static const svn_version_t name = \
+    { \
+      SVN_VER_MAJOR, \
+      SVN_VER_MINOR, \
+      SVN_VER_PATCH, \
+      SVN_VER_NUMTAG \
+    } \
+
+/**
+ * Generate the implementation of a version query function.
+ * @since New in 1.1.
+ */
+#define SVN_VERSION_BODY \
+  SVN_VERSION_DEFINE (versioninfo); \
+  return &versioninfo
+
+/**
+ * Check library version compatibility. Returns #TRUE if the clent's
+ * version, given in @a my_version, is compatible with the library
+ * version, provided in @a lib_version.
+ *
+ * This function checks for version compatibility as per our
+ * guarantees, but requires an exact match when linking to an
+ * unreleased library. A development client is always compatible with
+ * a previous released library.
+ *
+ * @since New in 1.1.
+ */
+svn_boolean_t svn_ver_compatible (const svn_version_t *my_version,
+                                  const svn_version_t *lib_version);
+
+
+/**
+ * An entry in the compatibility checklist.
+ * @see svn_ver_check_list()
+ * @since New in 1.1.
+ */
+typedef struct svn_version_checklist_t
+{
+  const char *label;            /**< Entry label */
+
+  /** Version query function for this entry */
+  const svn_version_t *(*version_query) (void);
+} svn_version_checklist_t;
+
+
+/**
+ * Perform a series of version compatibility checks. Checks if @a
+ * my_version is compatible with each entry in @a checklist. @a
+ * checklist must end with an entry whose label is @c NULL.
+ *
+ * @see svn_ver_compatible()
+ * @since New in 1.1.
+ */
+svn_error_t *svn_ver_check_list (const svn_version_t *my_version,
+                                 const svn_version_checklist_t *checklist);
+
+
+/* libsvn_subr doesn't have an svn_subr header, so put the prototype here. */
+/**
+ * Get libsvn_subr version information.
+ * @since New in version 1.1.
+ */
+const svn_version_t *svn_subr_version (void);
 
 
 #ifdef __cplusplus
